Module libsql_client::connection
source · Expand description
Connection is the main structure to interact with the database.
Traits
Trait describing capabilities of a database connection:
Connection is the main structure to interact with the database.